@@ -1,7 +1,7 @@
 import os
 import subprocess
-import shelve 
-import sys 
+import shelve
+import sys
 import Core
 import Parsers
 from blinker import signal
@@ -36,10 +36,10 @@ class Reader():
             exit("You need at least one file format configured. Check your wrangler.yaml file.")
 
         for cls in Core.Parser.__subclasses__():
-            
+
             if hasattr(cls, "accepts"):
                 acceptable_types = []
-                parser = cls(self.input_dir, "")
+                parser = cls(self.input_dir, self.config)
                 for file_format in cls.accepts:
                     if formats_allowed_by_config:
                         if file_format in formats_allowed_by_config:
@@ -61,16 +61,27 @@ class Reader():
                 self.classes[self.default_class] = cls
                 self.reporter.verbose("Set default class to new default subclass '%s'" % (cls.__name__), "blue")
 
-           
 
-    def load_class(self, file_class):
-        if not file_class in self.classes:
-            for cls in Core.Page.__subclasses__():
-                if cls.__name__ == file_class:
-                    self.classes[file_class] = cls
-                    self.reporter.verbose("Loaded class %s" % (file_class), "blue")
 
-        return self.classes[file_class]
+    def load_class(self, className):
+
+        def walkClass(cls, name):
+            for subclass in cls.__subclasses__():
+                if subclass.__name__ == name:
+                    return subclass;
+                else:
+                    res =  walkClass(subclass, name)
+                    if res:
+                        return res
+
+        if not className in self.classes:
+            new_class = walkClass(Core.Page, className)
+
+            if new_class:
+                self.classes[className] = new_class
+                self.reporter.verbose("Loaded class %s" % (className), "blue")
+
+        return self.classes[className]
 
 
     def init_cache(self):
@@ -83,8 +94,8 @@ class Reader():
             return shelve.open(self.config['wrangler']['build_cache_file'])
         except:
             self.reporter.log("Couldn't open cache at %s. Try running `wrangler clean`" % (self.config['wrangler']['build_cache_file']), "red")
-            exit() 
-    
+            exit()
+
     def save_cache(self, shelf):
         try:
             shelf.sync()
@@ -118,7 +129,7 @@ class Reader():
             node.tag = 'file'
 
             if basename.startswith("index") and basename.endswith(tuple(self.data_formats)):
-                node.is_index = True 
+                node.is_index = True
             return node
 
 
@@ -133,14 +144,14 @@ class Reader():
 
                     if filename.startswith("index") and filename.endswith(tuple(self.data_formats)):
                         a_cargo = _child.get_cargo()
-               
+
         if not b_cargo:
             if b.tag == "dir":
                 for _child in b.children:
                     filename = os.path.basename(_child.path)
                     if filename.startswith("index") and filename.endswith(tuple(self.data_formats)):
                         b_cargo = _child.get_cargo()
-                       
+
         try:
             a_weight = a_cargo.get_weight()
         except:
@@ -173,11 +184,11 @@ class Reader():
         self.graph = Core.NodeGraph()
         root_node = self.dir_as_tree(self.input_dir)
         self.graph.root(root_node)
-        
+
         for key, node in self.graph.all().items():
             if node.tag == "file":
                 node.add_cargo(self.new_item(shelf, node.path))
-        
+
         self.recursive_sort(root_node)
         self.save_cache(shelf)
 
@@ -185,7 +196,7 @@ class Reader():
 
 
     def load_parser_by_format(self, data_format):
-        try: 
+        try:
             return self.parsers[data_format]
         except:
             self.reporter.verbose("No parser found for %s" % (data_format), "red")
@@ -202,6 +213,7 @@ class Reader():
             print "Oops! Couldn't load \"%s\". Check the path exists." % (filename)
             return False
 
+
         if shelf.has_key(filename):
             try:
                 last_modified = shelf[filename].get_mtime()
@@ -211,22 +223,27 @@ class Reader():
 
 
         if (not shelf.has_key(filename)) or (last_modified < mtime) or (self.nocache):
-            
-            # Check if custom class is set, otherwise make it a page... 
+
+            # Check if custom class is set, otherwise make it a page...
             if parser:
                 page_data = parser.load(filename);
 
-                if page_data:
-                    page_classname = self.default_class
+                if page_data == None:
+                    if shelf.has_key(filename):
+                        shelf.pop(filename, None)
+                    return
 
-                    if "class" in page_data["meta"] and page_data["meta"]["class"] != None:
-                        page_classname = page_data["meta"]["class"]
+                page_classname = self.default_class
+
+                if "class" in page_data["meta"] and page_data["meta"]["class"] != None:
+                    page_classname = page_data["meta"]["class"]
+
+                PageClass = self.load_class(page_classname)
+                new_page = PageClass(page_data, self.config)
+                shelf[filename] = new_page
+                print "\033[1;35mCaching \033[0m\033[2m%s\033[0m" % (filename)
+                return new_page
 
-                    PageClass = self.load_class(page_classname)
-                    new_page = PageClass(page_data, self.config)
-                    shelf[filename] = new_page
-                    print "\033[1;35mCaching \033[0m\033[2m%s\033[0m" % (filename)
-                    return new_page
         else:
             if filename in shelf:
                 return shelf[filename]
